<?php

namespace KiwiCommerce\LoginAsCustomer\Plugin\Sales\Block\Adminhtml\Order;

use Magento\Sales\Block\Adminhtml\Order\View as OrderView;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Customer\Model\ResourceModel\CustomerRepository;
use Magento\Store\Model\ScopeInterface;
use Magento\Framework\UrlInterface;

class View
{
    /**
     * @var CustomerRepository
     */
    protected $customer;

    /**
     * @var ScopeConfigInterface
     */
    protected $_config;

    /**
     * @var UrlInterface
     */
    protected $_urlBuilder;

    /**
     * @param CustomerRepository $customer
     * @param ScopeConfigInterface $config
     * @param UrlInterface $urlBuilder
     */
    public function __construct(
        CustomerRepository $customer,
        ScopeConfigInterface $config,
        UrlInterface $urlBuilder
    )
    {
        $this->customer = $customer;
        $this->_config = $config;
        $this->_urlBuilder = $urlBuilder;
    }

    public function beforeSetLayout(OrderView $view)
    {
        $order = $view->getOrder();

        /*Check order is exist or not */

        if (!$order) {
            return;
        }

        /*Check ACL config*/
        $hidden = $view->getAuthorization()->isAllowed('KiwiCommerce_LoginAsCustomer::OrderGrid');

        $checkCustomerId = $view->getOrder()->getCustomerId();

        try {
            /* Check customer is exist in customer table or not if not then return on detail page */

            $this->customer->getById($checkCustomerId)->getId();
        } catch (\Exception $e) {
            return;
        }

        /*Check config setting is on or not for show the login as customer tab*/

        $loginAsCustomerEnabled = $this->_config->getValue(
            'kiwicommerce/general/login_as_customer_enabled',
            ScopeInterface::SCOPE_STORE
        );

        /*Check condition for order view page*/

        $orderViewPage = $this->_config->getValue(
            'kiwicommerce/button_visibility/order_view_page',
            ScopeInterface::SCOPE_STORE
        );

        /*Code for show the tab*/

        if ($loginAsCustomerEnabled == "1"
            && $orderViewPage == "1"
            && isset($checkCustomerId)
            && $hidden == "1"

        ) {
            $urlData = $this->_urlBuilder->getUrl(
                'loginascustomer/loginascustomer/login',
                ['customer_id' => $checkCustomerId, 'login_from' => 3]
            );
            $view->addButton(
                'loginascustomer',
                [
                    'label' => __('Login As Customer'),
                    'class' => 'loginascustomer',
                    'onclick' => 'window.open(\'' . $urlData . '\', \'_blank\')'
                ]
            );
        }
    }
}